# BASIC PACKAGES AND FUNCTIONS

# packages --------------------------------------------

if (!require("pacman")) install.packages("pacman")
pkgs<-c("cowplot", "plyr","tidyverse", "ggfortify", "scales", "lubridate", "reshape", "moments", "data.table")
pacman::p_load(char=pkgs,install=T)
cat(paste("Basic packages loaded:", paste(pkgs,collapse=", ")), fill=T)
rm(pkgs)

# functions --------------------------------------------

summ <- function(x, value.cols=NULL, by=NULL, mean_only=F, na.rm=T){
  x <- setDT(x)
  if(mean_only==T){
    summ = x[, sapply(.SD, m_se), by=by, .SDcols=value.cols]
    setnames(summ, (length(by)+1):length(summ), CJ(value.cols, c("mean","se"), sorted = FALSE)[, paste(V1, V2, sep ="_")])
  }
  else {
    summ <- x[, psych::describe(.SD, na.rm = na.rm),  by=by, .SDcols=value.cols]
    summ$vars = factor(summ$vars)
    setattr(summ[["vars"]],"levels",value.cols)
    setnames(summ, (length(by)+2):length(summ), 
             c("N", "Mean", "SD", "Median", "Trimmed", 
               "Mad", "Min", "Max", "Range", "Skewness", "Kurtosis", "SE"))
  }
  return(summ)
}

AC <- function(x) ( (acf(x,plot=F, na.action=na.pass)[1][[1]][1]))

CV <- function(x){ 
  x = x[complete.cases(x)]
  y=if(min(x)<=0) (x+abs(min(x))) else(x)
  (sd(y)/mean(y))}

m_r = function(x, digits=10) MEAN = round(mean(x, na.rm=T), digits)

m_se = function(x, digits=10) list(MEAN = round(mean(x, na.rm=T),digits), SE = round((sd(x,na.rm=T) / sqrt(length(x))), digits))

#   datac$SE <- datac$SD / sqrt(datac$N)  # Calculate standard error of the mean

# 
# 
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=T, conf.interval=.95, .drop=TRUE) {

  if (na.rm==T){input<-data[complete.cases(data[measurevar]),]}
  else {input<-data}

    datac <- ddply(input, groupvars, .drop=.drop,
                 .fun= function(xx, col) {
                   c( N    = length (xx[,col]),
                      Mean = mean   (xx[,col]),
                      SD   = sd     (xx[,col]),
                      CV = ((sd(xx[,col])/mean(xx[,col]))),
                      Sum = sum(xx[,col]),
                      Median = median(xx[,col]),
                      # IQR = IQR(xx[,col]),
                      # Min = quantile(xx[,col])[[1]],
                      # Q25 = quantile(xx[,col])[[2]],
                      # Q75 = quantile(xx[,col])[[4]],
                     #  Max = quantile(xx[,col])[[5]],
                      Skewness = skewness   (xx[,col]),
                      Kurtosis = kurtosis   (xx[,col]),
                      Outliers=length(boxplot.stats((xx[,col]))$out)
                   )
                 },
                 measurevar
  )




  # Rename the "mean" column
  # datac <- rename(datac, c("mean"=measurevar))

  datac$SE <- datac$SD / sqrt(datac$N)  # Calculate standard error of the mean

  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval:
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$CI <- datac$SE * ciMult

  return(datac)

}
# 
# 
# 
