## created 2018-03-29
## las modified 2020-10-27
## by Moritz Lrig 

# header -----------------------------------------------------------------

## startup chunk

## set to root of zipped folder
setwd("D:/FB_luerig_macrophytes")

# rm(list = ls())

## tese are function collections needed to execute the script
source("R/basic.R")
source("R/plotting.R")
source("R/timeseries.R")

pacman::p_load(char=c("effsize"),install=T)

# sepcify parameters
treat.col<-c("#33a02c", "#1f78b4")
para.col=c( '#1b9e77','#66a61e','#d95f02', '#7570b3','#e6ab02','#e7298a')
parameters = c("Chlorophyll_RFU", "BGAPC_RFU", "fDOM_RFU", "ODO_sat", "SpCond_uScm")


# raw data --------------------------------------------------------------------

## this is the corrected, full dataset. for details on how we processed it see the methods section of the paper.
## in short: raw data > outlier removal > correction/calibration > sliding windows > analysis & figures

# load full data (needed for figure s2)
all<-fread("data/data-corr-all.txt")

# figure 1  -------------------------------------------------------------------

## (manually created schematic)

# figure 2 ----------------------------------------------------
## this first bit does summary stats on the sliding window data. since the processed data is provided, this bit is commented out
# cv_frame<-read.delim("data/ews-frame-0.15-winsize.txt", header=T)
# 
# summ1<-summarySE(cv_frame, measurevar = "Mean", groupvars = c("Macrophytes", "Time_ind", "Temporal_block", "Parameter"))
# summ1<-new.summ(cv_frame, var = "Max", 
#                 by = c("Macrophytes", "Temporal_block", "Parameter"))
# 
# summ1a<-summ1 %>%
#   group_by(interaction(Macrophytes, Temporal_block)) %>%
#   slice(5:(n()-20))
# 
# setDT(summ1a)
# summ1a[ , `:=`(Time_ind = 1:.N ) , by = interaction(Temporal_block, Macrophytes, Parameter) ]
# summ1a<-as.data.frame(summ1a)
# 
# write.table(summ1a, "data/ews-mean-summ.txt", sep="\t")

## load summarized sliding window data
summ1a<-read.delim("data/ews-mean-summ.txt", header=T)
summ1a<-arrange(summ1a, Parameter, Macrophytes, Time_ind)

summ1a$Temporal_block<-factor(summ1a$Temporal_block)
levels(summ1a$Temporal_block)<-c("t1\n 07/18 - 08/07",
                                 "t2\n 08/07 - 08/27",
                                 "t3\n 09/05 - 09/25",
                                 "t4\n 09/25 - 10/09",
                                 "t5\n 10/09 - 10/23")

summ2<-read.delim("data/ews-cv-summ.txt", header=T)

summ2$Temporal_block<-factor(summ2$Temporal_block)
levels(summ2$Temporal_block)<-c("t1\n 07/18 - 08/07",
                                "t2\n 08/07 - 08/27",
                                "t3\n 09/05 - 09/25",
                                "t4\n 09/25 - 10/09",
                                "t5\n 10/09 - 10/23")

p1<-ggplot(subset(summ1a, Parameter=="Chlorophyll_RFU")) + theme_cowplot() +
  ylab(expression(atop(Chlorophyll~A,~(paste(mu,g)~L^{-1})))) +  
  #coord_cartesian(ylim = c(0,20)) +
  geom_line(aes(x=Time_ind, y=(Mean*4.7)-1,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=(Mean*4.7-SE*4.7)-1, ymax=(Mean*4.7+SE*4.7)-1, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(1,738,96)) + 
  scale_y_continuous(expand = c(0,0), breaks = c(0, 4, 8, 12, 16)) + 
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 30.75, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1, size = 1),
        strip.text.x = element_text(size = 9),
        plot.margin=unit(c(1,1,-0.1,1), "cm"))

p2<-ggplot(subset(summ2, Parameter=="Chlorophyll_RFU")) + theme_cowplot() +
  ylab(expression(atop(Chlorophyll~A,(CV)))) +  #coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(1,738,96)) + 
  scale_y_continuous(expand = c(0,0)) + #
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        plot.margin=unit(c(0,1,-0.1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 27.75, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))

p3<-ggplot(subset(summ1a, Parameter=="BGAPC_RFU")) + theme_cowplot() +
  ylab(expression(atop(Phycocyanin,(raw~fluorescence)))) +  #coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(1,738,96)) + 
  # scale_y_continuous(expand = c(0,0), breaks = c(0, 1, 2),limits=c(0,2.8)) +
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        plot.margin=unit(c(0,1,-0.1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 27, b = 0, l = 1), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))

p4<-ggplot(subset(summ2, Parameter=="BGAPC_RFU")) + theme_cowplot() +
  ylab(expression(atop(Phycocyanin,("CV")))) +  #coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(0,738,96), labels = c(2:9)) + 
  # scale_y_continuous(expand = c(0,0),  breaks = c(80,100, 120),limits=c(70,140)) + #
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col, labels=c("M+","M-")) +
  scale_colour_manual(values=treat.col, labels=c("M+","M-")) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        plot.margin=unit(c(0,1,1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 21.25, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))


png("figures/figure2.png", width = 7, height = 8.6, units = 'in', res = 300)
grid.arrange(p1,p2,p3, p4, ncol=1, heights=c(5.5,4, 4,6.4))
dev.off()


# figure 3 ----------------------------------------------------------------
## this first bit does summary stats on the sliding window data. since the processed data is provided, this bit is commented out
# cv_frame<-read.delim("data/ews-frame-0.15-winsize.txt", header=T)
# 
# summ2<-summarySE(cv_frame, measurevar = "SD", groupvars = c("Macrophytes", "Time_ind", "Temporal_block", "Parameter"))
# 
# setDT(summ2)
# summ2[ , `:=`(Time_ind = 1:.N ) , by = interaction(Temporal_block, Macrophytes, Parameter) ]
# summ2<-as.data.frame(summ2)
# 
# summ2<-arrange(summ2, Time_ind, Macrophytes, Parameter, Temporal_block)
# 
# summ2<-summ2 %>%
#   group_by(interaction(Macrophytes, Parameter, Temporal_block)) %>%
#     slice(3:(n()-12))
# 
# 
# write.table(summ2, "data/ews-sd-summ.txt", sep="\t")

## load summarized sliding window data
summ1a<-read.delim("data/ews-mean-summ.txt", header=T)
summ1a<-arrange(summ1a, Parameter, Macrophytes, Time_ind)

summ1a$Temporal_block<-factor(summ1a$Temporal_block)
levels(summ1a$Temporal_block)<-c("t1\n 07/18 - 08/07",
                                 "t2\n 08/07 - 08/27",
                                 "t3\n 09/05 - 09/25",
                                 "t4\n 09/25 - 10/09",
                                 "t5\n 10/09 - 10/23")

summ2<-read.delim("data/ews-cv-summ.txt", header=T)

summ2$Temporal_block<-factor(summ2$Temporal_block)
levels(summ2$Temporal_block)<-c("t1\n 07/18 - 08/07",
                                "t2\n 08/07 - 08/27",
                                "t3\n 09/05 - 09/25",
                                "t4\n 09/25 - 10/09",
                                "t5\n 10/09 - 10/23")


p5<-ggplot(subset(summ1a, Parameter=="fDOM_RFU")) + theme_cowplot() +
  ylab(expression(atop(DOM,(raw~fluorescence)))) +  
  geom_line(aes(x=Time_ind, y=Mean-1,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-SE-1, ymax=Mean+SE-1, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(1,738,96)) + 
  scale_y_continuous(expand = c(0,0), breaks = c(0, 1, 2),limits=c(0,2.8)) +
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        strip.text.x = element_text(size = 9),
        axis.title.y = element_text(margin = margin(t = 0, r = 41, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1, size = 1),
        plot.margin=unit(c(1,1,-0.2,1), "cm"))


p6<-ggplot(subset(summ2, Parameter=="fDOM_RFU")) + theme_cowplot() +
  ylab(expression(atop(DOM,(CV)))) +  
  coord_cartesian(ylim = c(0,0.25)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-CI, ymax=Mean+CI, fill=Macrophytes), alpha=0.5)  +
  scale_x_continuous(breaks=seq(1,738,96), limits=c(1,738)) + 
  scale_y_continuous(expand = c(0,0),  breaks=c(0, 0.05, 0.1, 0.15, 0.2)) + 
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        plot.margin=unit(c(0,1,-0.1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 23, b = 0, l = 1), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))


p7<-ggplot(subset(summ1a, Parameter=="ODO_sat")) + theme_cowplot() +
  ylab(expression(atop(O[2]~saturation,("%")))) +  #coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) + 
  scale_x_continuous(breaks=seq(0,738,96), labels = c(2:9)) + 
  scale_y_continuous(expand = c(0,0),  breaks = c(80,100, 120),limits=c(70,140)) + #
  facet_wrap(~Temporal_block, ncol=5) +
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        plot.margin=unit(c(0,1,-0.1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 26.5, b = 0, l = 1), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))


p8<-ggplot(subset(summ2, Parameter=="ODO_sat")) + theme_cowplot() +
  ylab(expression(atop(O[2]~saturation,(CV)))) +
  coord_cartesian(ylim = c(0,0.2)) +
  geom_line(aes(x=Time_ind, y=Mean,colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Time_ind, ymin=Mean-CI, ymax=Mean+CI, fill=Macrophytes), alpha=0.5)  +
  scale_x_continuous(breaks=seq(1,738,96), limits=c(1,738), labels = c(2:9)) + 
  scale_y_continuous(expand = c(0,0), breaks=c(0, 0.05, 0.1, 0.15)) + 
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_fill_manual(values=treat.col, labels = c("M+", "M-")) +
  scale_colour_manual(values=treat.col, labels = c("M+", "M-")) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        plot.margin=unit(c(0,1,1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 23, b = 0, l = 1), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))

png("figures/figure3.png", width = 7, height = 8.6, units = 'in', res = 300)
grid.arrange(p5,p6,p7,p8, ncol=1, heights=c(5.5,4, 4,6.4))
dev.off()

# figure 4 ----------------------------------------------------------

# metabolism
metab <- read.table("data/metab-bayes.txt", head=T)
metab$Date<-ymd(metab$Date)

metab<-arrange(metab, Date_num, Macrophytes, Temporal_block)
metab$ER.daily<-abs(metab$ER.daily)+0.5
metab$GPP.daily<-abs(metab$GPP.daily)+0.5
metab$ratio<-metab$GPP.daily/metab$ER.daily
metab$Temporal_block<-factor(metab$Temporal_block)

gpp.sum<-summarySE(metab, measurevar = "GPP.daily", groupvars = c("Macrophytes", "Date_num","Temporal_block"))
er.sum<-summarySE(metab, measurevar = "ER.daily", groupvars = c("Macrophytes", "Date_num","Temporal_block"))
ratio.sum<-summarySE(metab, measurevar = "ratio", groupvars = c("Macrophytes", "Date_num","Temporal_block"))

gpp.sum<-arrange(gpp.sum, Temporal_block, Date_num, Macrophytes)
er.sum<-arrange(er.sum, Temporal_block, Date_num, Macrophytes)
ratio.sum<-arrange(ratio.sum, Temporal_block, Date_num, Macrophytes)


p1<-ggplot(gpp.sum) +  ylab(expression(atop(GPP,(g~O[2]~m^{-2}~d^{-1})))) + theme_cowplot() +
  coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Date_num, y=Mean, colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Date_num, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) +
  scale_x_continuous(breaks=seq(1,8,1)) +
  scale_y_continuous(expand = c(0,0), breaks=c(0,1,2,3)) +
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        strip.text.x = element_text(size = 9),
        axis.title.y = element_text(margin = margin(t = 0, r = 31, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1, size = 1),
        plot.margin=unit(c(1,1,-0.1,1), "cm"))

p2<-ggplot(er.sum) + ylab(expression(atop(ER,(g~O[2]~m^{-2}~d^{-1})))) + theme_cowplot() +
  coord_cartesian(ylim = c(0,4)) +
  geom_line(aes(x=Date_num, y=Mean, colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Date_num, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) +
  scale_x_continuous(breaks=seq(1,8,1)) +
  scale_y_continuous(expand = c(0,0), breaks=c(0,1,2,3)) +
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        plot.margin=unit(c(0,1,-0.1,1), "cm"),
        strip.text.x = element_blank(),
        #panel.spacing = unit(0.8, "lines"), 
        axis.title.y = element_text(margin = margin(t = 0, r = 31, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))

p3<-ggplot(ratio.sum) + ylab("GPP:ER") + theme_cowplot() +
  geom_line(aes(x=Date_num, y=Mean, colour=Macrophytes), size=1) +
  geom_ribbon(aes(x=Date_num, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes), alpha=0.5) +
  geom_abline(slope=0, intercept=1) +
  scale_x_continuous(breaks=seq(1,8,1), labels=c(1:8)) +
  scale_y_continuous(expand = c(0,0)) +
  facet_wrap(~Temporal_block, ncol=5) +
  scale_fill_manual(values=treat.col, labels = c("M+", "M-")) +
  scale_colour_manual(values=treat.col, labels = c("M+", "M-")) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        axis.title.x=element_blank(),
        plot.margin=unit(c(0,1,1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 36.5, b = 0, l = 8), size=12),
        #panel.spacing = unit(0.8, "lines"), 
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1))

png("figures/figure4.png", width = 7, height = 8, units = 'in', res = 300)
grid.arrange(p1,p2, p3, ncol=1, heights=c(5,3.7, 5.5))
dev.off()

# figure 5 ----------------------------------------------------------

## (manually created figure with Matlab output)

# figure 6 ------------------------------------------------------------------

## here all the available data (from sliding windows, metabolism modelling and manual DOC measurements) gets merged into one dataframe

## sliding windows

c<-fread("data/ews-frame-0.15-winsize.txt")
c[,day:=Time_ind/96]

c[,c("V1", "Tank", "Tank_set", "SD", "AC", "day"):=NULL]
c = c[Parameter != "Temp_C"]
c[, Parameter := as.character(factor(Parameter, labels = c("Phycocyanin","Chlorophyll", "DOM", "O2 sat.", "Sp. conductivity")))]

c.w = data.table::dcast(c, Temporal_block + Time_ind + Parameter + Physical_block ~ Macrophytes , value.var = c("Mean","CV"))
c.w = c.w[complete.cases(c.w),]
c.w[,lrr_mean:=log(Mean_Macrophytes/Mean_No_macrophytes)]
c.w[,lrr_cv:=log(CV_Macrophytes/CV_No_macrophytes)]
c.w[,c("Mean_Macrophytes", "Mean_No_macrophytes", "CV_Macrophytes", "CV_No_macrophytes", "Time_ind"):=NULL]

summ = function(x) list(mean = mean(x), se =sd(x)/sqrt(length(x)))
c.s=c.w[,sapply(.SD, summ), by=c("Temporal_block", "Physical_block", "Parameter"),.SDcols=c("lrr_mean", "lrr_cv")]
setnames(c.s, 4:7, c("lrr_mean_mean","lrr_mean_se", "lrr_cv_mean", "lrr_cv_se"))
c.s=c.s[,sapply(.SD, summ), by=c("Temporal_block", "Parameter"),.SDcols=c("lrr_mean_mean", "lrr_cv_mean")]
setnames(c.s, 3:6, c("lrr_mean_mean","lrr_mean_se", "lrr_cv_mean", "lrr_cv_se"))

## manual

nut<-read.table("data/man-doc-sub.txt", header = T, sep="\t")
parameters = c("DOC", "abs254", "abs350",  "ssr")

dt = data.table(nut[,c("Date", "Macrophytes", "Physical_block", "DOC", "abs254", "abs350",  "ssr")])
id = data.table(Date= unique(dt$Date), Temporal_block = c("t1", "t1", "t2", "t2" , "t3", "t3", "t4", "t4", "t5", "t5"))
dt = merge(dt, id)

dt.l = melt(dt, id.vars = c("Date", "Temporal_block", "Physical_block", "Macrophytes"), measure.vars = parameters)
dt.w = dcast(dt.l, Date + Physical_block + variable ~ Macrophytes , value.var = "value")
dt.w[,LRR := log(Macrophytes/No_macrophytes)]

d=dt.w[variable=="DOC",]


dt.s = summarySE(data.frame(dt.w), measurevar = "LRR", groupvars = c("variable", "Physical_block"))
dt.ss2 = summarySE(dt.s, measurevar = "Mean", groupvars = c("variable"))
dt.ss3 = summarySE(data.frame(dt.l), measurevar = "value", groupvars=c("Physical_block", "variable","Macrophytes"))
dt.w2 = dcast(data.table(dt.ss3), Physical_block + variable ~ Macrophytes , value.var = "CV")
dt.w2$LRR = dt.w2$Macrophytes/dt.w2$No_macrophytes
dt.ss4 = dt.w2[, m_se(LRR),by="variable"]


t <- data.table(dt.ss2[,c("variable","Mean","SE")])
t[,c("lrr_cv_mean" , "lrr_cv_se") := dt.ss4[,c("MEAN","SE")]]
t[,Temporal_block:=" "]
t = t[,c( "Temporal_block", "variable", "Mean", "SE", "lrr_cv_mean", 
          "lrr_cv_se")]
setnames(t, c("Temporal_block", "Parameter", "lrr_mean_mean", "lrr_mean_se", 
              "lrr_cv_mean", "lrr_cv_se"))

c.s1<-rbind(c.s, t)

## metabolism data

dt = data.table(metab[,c("Date", "Macrophytes", "Physical_block", "Temporal_block", "GPP.daily", "ER.daily")])
dt[,Temporal_block:=substr(dt$Temporal_block,1,2)]
dt.l = melt(dt, id.vars = c("Date","Temporal_block", "Physical_block", "Macrophytes"), measure.vars = c("GPP.daily", "ER.daily"))
dt.w = dcast(dt.l, Date + Temporal_block + Physical_block + variable ~ Macrophytes , value.var = "value")
dt.w[,LRR := log(Macrophytes/No_macrophytes)]

dt.ss3 = summarySE(data.frame(dt.l), measurevar = "value", groupvars=c("Physical_block", "variable","Macrophytes", "Temporal_block"))
dt.w2 = dcast(dt.ss3, Physical_block + Temporal_block + variable ~ Macrophytes , value.var = "CV")
dt.w2$LRR = dt.w2$Macrophytes/dt.w2$No_macrophytes
dt.ss4 = summarySE(dt.w2, measurevar="LRR", groupvars = c("variable","Temporal_block"))


dt.s = summarySE(data.frame(dt.w), measurevar = "LRR", groupvars = c("variable", "Temporal_block","Physical_block"))
dt.ss1 = summarySE(dt.s, measurevar = "Mean", groupvars = c("variable", "Temporal_block"))

t <- data.table(dt.ss1[,c("Temporal_block","variable","Mean","SE")])
t[,c("lrr_cv_mean" , "lrr_cv_se") := dt.ss4[,c("Mean","SE")]]
t = t[,c( "Temporal_block", "variable", "Mean", "SE", "lrr_cv_mean", 
          "lrr_cv_se")]
setnames(t, c("Temporal_block", "Parameter", "lrr_mean_mean", "lrr_mean_se", 
              "lrr_cv_mean", "lrr_cv_se"))

c.s2<-rbind(c.s1, t)

type <- data.frame(Parameter=unique(c.s2$Parameter),Type=c(rep("h",5), rep("p",4), "m","m"))
c.s3 <- merge(c.s2, type)
c.s3$Type = factor(c.s3$Type, levels=c("h","m","p"))

## plotting

png("figures/figure6.png", width = 8, height = 8, units = 'in', res = 300)
ggplot(c.s3) + ylab("LRR CV") + xlab("LRR mean") + theme_cowplot() +
  coord_cartesian(ylim=c(-1,2), xlim=c(-1,0.5)) +
  geom_hline(yintercept = 0) +
  geom_vline(xintercept = 0) +
  geom_point(aes(x=lrr_mean_mean, y=lrr_cv_mean, colour=Parameter, shape=Type), size=6) +
  geom_errorbar(aes(x=lrr_mean_mean, ymin=lrr_cv_mean-lrr_cv_se, ymax=lrr_cv_mean+lrr_cv_se, colour=Parameter), width=0) +
  geom_errorbarh(aes(y=lrr_cv_mean, xmin=lrr_mean_mean-lrr_mean_se, xmax=lrr_mean_mean+lrr_mean_se, colour=Parameter), height=0) +
  scale_color_manual(labels=c("Chlorophyll-a", "Phycocyanin", "fDOM", "Dissolved oxygen", "Conductivity", "Total DOC",
                              expression(SUVA[254]), expression(SUVA[350], "SSR", "GPP", "ER")), 
                     values = c('#4daf4a','#ff7f00', '#377eb8','#984ea3','#e41a1c', "#1a1a1a", "#8c510a", "#abdda4", "#d9d9d9", "#8dd3c7","#c51b7d")) +
  scale_shape_manual(labels = c("High frequency","Metabolism", "DOC"), values=c(16, 17, 15))+
  geom_text(aes(x=lrr_mean_mean, y=lrr_cv_mean, group=Parameter, label=Temporal_block), 
            colour = "white") +
  theme(legend.position="bottom",
        legend.title = element_blank(),
        legend.key.width = unit(1.5,"cm"),
        legend.text.align=0) +  
  guides(col = guide_legend(ncol = 4, override.aes = list(pch=c(rep(21,5),rep(22,4),rep(24,2)),
                                                          fill=c('#4daf4a','#ff7f00', '#377eb8','#984ea3',
                                                                 '#e41a1c', "#1a1a1a", "#8c510a", "#abdda4", "#d9d9d9", "#8dd3c7","#c51b7d"))),
         shape = FALSE)
dev.off()




# figure s1 ---------------------------------------------------------------

nut<-read.delim("data/man-doc-sub.txt", header = T, sep="\t")
nut<-nut[complete.cases(nut$DN),]

summ1<-summarySE(nut, measurevar="DP", groupvars = c("Date","Macrophytes"))
summ1$Date<-ymd(summ1$Date)
summ1$Mean<-summ1$Mean+0.5

summ2<-summarySE(nut, measurevar="DN", groupvars = c("Date","Macrophytes"))
summ2$Date<-ymd(summ2$Date)


p1<-ggplot(summ1) + xlab("Date") + ylab(expression(g~P~L^{-1})) +  theme_cowplot() +
  geom_line(aes(x=factor(Date), y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=factor(Date), ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_x_discrete(labels=substr(unique(summ1$Date),6,10)) +
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  theme(
    legend.position = "null",
    axis.title.x = element_blank()
  )

p2<-ggplot(summ2) + xlab("Date") + ylab(expression(g~N~L^{-1})) +  theme_cowplot() +
  geom_line(aes(x=factor(Date), y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=factor(Date), ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_y_continuous(breaks = c(10, 15, 20, 25, 30, 35)) +
  scale_x_discrete(labels=substr(unique(summ1$Date),6,10)) +
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  theme(legend.position = "bottom",
        legend.box = "vertical",
        legend.justification = "center",
        legend.title = element_blank(),
        axis.title.x = element_blank()
  )


png("figures/figureS1.png", width = 4, height = 6.5, units = 'in', res = 300)
grid.arrange(p1,p2, ncol=1, heights=c(0.9, 1))
dev.off()


# figure s2 ----------------------------------------------------------------

date.breaks<-structure(c(1437264000, 1438040700+43650, 1438904700, 
                         1438992000, 1439768700+43650, 1440632700, 
                         1441497600, 1442274300+43650, 1443138300, 
                         1443225600, 1443743100+43650, 1444347900,
                         1444435200, 1444952700+43650, 1445557500+900), 
                       class = c("POSIXct", "POSIXt"
                       ), tzone = "UTC")

summa = all[, mean(PAR), by=c("Date_time", "Temporal_block","Tank_set")]
setnames(summa, "V1", "Mean")
summb = all[, mean(Temp_C), by=c("Date_time", "Temporal_block","Tank_set")]
setnames(summb, "V1", "Mean")

p1<-ggplot(summa) + theme_cowplot() +
  ylab(expression(atop(PAR,~(mol~m^{-2}~s^{-1})))) + 
  geom_line(aes(x=Date_time, y=Mean, group=Tank_set), size=1) +
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_y_continuous(expand = c(0.0,0), limits=c(0, 1100)) + #
  scale_x_datetime(expand = c(0,0), breaks=date.breaks, date_label="%b %d") + #
  theme(legend.position = "bottom",
        axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 21.5, b = 0, l = 0), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1, size = 1),
        panel.spacing = unit(5, "mm"),
        plot.margin=unit(c(1,1,-0.4,1), "cm"))

summb[7488,"Date_time"] = "2015-10-23 02:00:00 UTC"

p2<-ggplot(summb) + theme_cowplot() +
  ylab(expression(atop(Temperature,("C")))) + 
  coord_cartesian(ylim = c(0,35)) +
  geom_line(aes(x=Date_time, y=Mean, group=Tank_set), size=1) +
  facet_wrap(~Temporal_block, ncol=5, scales="free_x") +
  scale_y_continuous(expand = c(0.0,0)) + #
  scale_x_datetime(expand = c(0,0),breaks=date.breaks, date_label="%b %d") + #
  theme(legend.position = "null",
        axis.title.x=element_blank(),
        axis.text.x=element_text(angle = 60, vjust = 1, hjust=1),
        plot.margin=unit(c(0,1,1,1), "cm"),
        strip.text.x = element_blank(),
        axis.title.y = element_text(margin = margin(t = 0, r = 32, b = 0, l = 1), size=12),
        strip.background  = element_rect(fill = "white", colour = "black", linetype=1),
        panel.spacing = unit(5, "mm"),
        axis.ticks.length = unit(2, "mm"))




png("figures/figureS2.png", width = 9, height = 7, units = 'in', res = 300)
grid.arrange(p1, p2, ncol=1, heights=c(4,4))
dev.off()




# figure s3  ------------------------------------------------
doc<-read.delim("data/man-doc-sub.txt", header = T, sep="\t")

sum.doc<-summarySE(doc, measurevar="DOC", groupvars = c("Date","Macrophytes"))
sum.doc$Date<-ymd(sum.doc$Date)
sum.254<-summarySE(doc, measurevar = "abs254a", groupvars = c("Date", "Macrophytes"))
sum.254$Date<-ymd(sum.254$Date)
sum.350<-summarySE(doc, measurevar = "abs350a", groupvars = c("Date", "Macrophytes"))
sum.350$Date<-ymd(sum.350$Date)
sum.ssr<-summarySE(doc, measurevar = "ssr", groupvars = c("Date", "Macrophytes"))
sum.ssr$Date<-ymd(sum.ssr$Date)

p0<-ggplot(sum.doc) + ylab("Total DOC \n mg/L") + theme_cowplot() +
  geom_line(aes(x=Date, y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=Date, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  theme(
    legend.position = "null",
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    plot.margin=unit(c(1,1,-0.1,1), "cm"),
    axis.title.y = element_text(margin = margin(t = 0, r = 31.75, b = 0, l = 1), size=12)
  )

p1<-ggplot(sum.254) + ylab(expression(SUVA[254])) + theme_cowplot() +
  coord_cartesian(ylim=c(0.047, 0.095)) +
  geom_line(aes(x=Date, y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=Date, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  scale_y_continuous(breaks=c(0.05, 0.06, 0.07, 0.08, 0.09)) +
  theme(
    legend.position = "null",
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    plot.margin=unit(c(0,1,-0.1,1), "cm"),
    axis.title.y = element_text(margin = margin(t = 0, r = 35.75, b = 0, l = 1), size=12)
  )

p2<-ggplot(sum.350) + ylab(expression(SUVA[350])) + theme_cowplot() +
  coord_cartesian(ylim=c(0.007, 0.021)) +
  geom_line(aes(x=Date, y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=Date, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  scale_y_continuous(breaks=c(0.008, 0.012, 0.016, 0.02)) +
  theme(
    legend.position = "null",
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    plot.margin=unit(c(0,1,-0.1,1), "cm"),
    axis.title.y = element_text(margin = margin(t = 0, r = 29, b = 0, l = 1), size=12)
  )

p3<-ggplot(sum.ssr) + ylab(expression(SSR)) +  theme_cowplot() +
  geom_line(aes(x=Date, y=Mean, colour=Macrophytes, group=Macrophytes), size=2) +
  geom_ribbon(aes(x=Date, ymin=Mean-SE, ymax=Mean+SE, fill=Macrophytes, group=Macrophytes), alpha=0.5) + 
  scale_color_manual(values=treat.col) +
  scale_fill_manual(values=treat.col) +
  scale_y_continuous(breaks=c(4.5, 5, 5.5, 6, 6.5), limits=c(4.3, 7.2)) +
  theme(
    legend.position = "null",
    axis.title.x = element_blank(),
    plot.margin=unit(c(-1.2,1,1,1), "cm"),
    axis.title.y = element_text(margin = margin(t = 0, r = 46.5, b = 0, l = 1), size=12)
  )


png("figures/figureS3.png", width = 6, height = 13, units = 'in', res = 300)
grid.arrange(p0, p1, p2, p3, ncol=1,heights=c(4.5, 4.2, 4.2, 4.8))
dev.off()

# figure s4 ---------------------------------------------------------------

metab$log_chl<-log10(metab$Chlorophyll_RFU*4.7)

p7<-ggplot(metab) +  ylab(expression(atop(GPP,(g~O[2]~m^{-2}~d^{-1})))) + xlab(expression(atop(log~Chlorophyll~a,~(mg~L^{-1})))) + theme_cowplot() +
  geom_point(aes(x=log_chl, y=GPP.daily, colour=Macrophytes, shape=Temporal_block), size=3) +
  geom_smooth(aes(x=log_chl, y=GPP.daily, colour=Macrophytes),  method="lm") +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  theme(legend.position = "null")

p8<-ggplot(metab) +  ylab(expression(atop(ER,(g~O[2]~m^{-2}~d^{-1})))) + xlab(expression(atop(log~Chlorophyll-a,~(mg~L^{-1})))) + theme_cowplot() +
  geom_point(aes(x=log_chl, y=ER.daily, colour=Macrophytes, shape=Temporal_block), size=3) +
  geom_smooth(aes(x=log_chl, y=ER.daily, colour=Macrophytes),  method="lm") +
  scale_fill_manual(values=treat.col) +
  scale_colour_manual(values=treat.col) +
  # guides(shape=guide_legend(ncol=2)) +
  theme(legend.position = "bottom",
        legend.box = "vertical",
        legend.justification = "center",
        legend.title = element_blank())


png("figures/figureS4.png", width = 5, height = 10, units = 'in', res = 300)
grid.arrange(p7,p8, ncol=1, heights=c(0.85, 1))
dev.off()
