# TIME SERIES ANALYSIS

# packages --------------------------------------------
if (!require("pacman")) install.packages("pacman")
pkgs<-c("bfast", "evd","earlywarnings", "trend")
pacman::p_load(char=pkgs,install=T)
cat(paste("Packages for time series analysis loaded:", paste(pkgs,collapse=", ")), fill=T)
rm(pkgs)


# functions --------------------------------------------
ts_outliers <- function(x,plot=FALSE)
{
  x <- as.ts(x)
  if(frequency(x)>1)
    resid <- stl(x,s.window="periodic",robust=TRUE)$time.series[,3]
  else
  {
    tt <- 1:length(x)
    resid <- residuals(loess(x ~ tt))
  }
  resid.q <- quantile(resid,prob=c(0.25,0.75))
  iqr <- diff(resid.q)
  limits <- resid.q + 2.5*iqr*c(-1,1)
  score <- abs(pmin((resid-limits[1])/iqr,0) + pmax((resid - limits[2])/iqr,0))
  if(plot)
  {
    plot(x)
    x2 <- ts(rep(NA,length(x)))
    x2[score>0] <- x[score>0]
    tsp(x2) <- tsp(x)
    points(x2,pch=19,col="red")
    return(invisible(score))
  }
  else
    return(score)
}


slideFunct <- function(data, winsize, step, value, id){
  total<-dim(data)[1]
  window<-round(dim(data)[1]*winsize/100)
  spots <- seq(from=1, to=(total-window)+1, by=step)
  Mean <- vector(length = length(spots))
  for(i in 1:length(spots)){
    Mean[i] <- mean(data[spots[i]:(spots[i]+window-1), value])
  }
  dummy1<-cbind(Mean, data[spots, id])
  dummy1$Time_ind<-spots+window-1
  return(dummy1)
}



##### summaryTS #####

AC <- function(x) ( (acf(x,plot=F, na.action=na.pass)[1][[1]][1]))


summaryTS <- function(data=NULL, measurevar, groupvars=NULL, na.rm=T, 
                      conf.interval=.95, .drop=TRUE, detrend=T) {

  if(detrend == T) {fit_GEV <- function(x) {fgev(x, std.err = FALSE,nsloc=predict(lm(x ~ seq_along(x))))$estimate[[4]]}}
  else {fit_GEV <- function(x) {fgev(x, std.err = FALSE)$estimate[[3]]}}
  
  if (na.rm==T){data<-data[complete.cases(data[measurevar]),]} 
  else {data<-data}
  
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun= function(xx, col) {
                   c( N    = length (xx[,col]),
                      Mean = mean   (xx[,col]),
                      SD   = sd     (xx[,col]),
                      CV = ((sd(xx[,col])/mean(xx[,col]))),
                      Sum = sum(xx[,col]),
                      Median = median(xx[,col]),
                      Min = quantile(xx[,col])[[1]],
                      Max = quantile(xx[,col])[[5]],
                      IQR = IQR(xx[,col]),
                      Q25 = quantile(xx[,col])[[2]],
                      Q75 = quantile(xx[,col])[[4]],
                      Skewness = skewness   (xx[,col]),
                      Kurtosis = kurtosis   (xx[,col]),
                      AC = AC (xx[,col]),
                      #ADF_test = suppressWarnings(adf.test(na.omit((xx[,col])), alternative = "stationary")$p.value),
                      GEV_shape = suppressMessages(fit_GEV((xx[,col]))),
                      Extremes=length(boxplot.stats((xx[,col]))$out)
                   )
                 },
                 measurevar
  )
  
  
  
  # Rename the "mean" column
  # datac <- rename(datac, c("mean"=measurevar))
  
  datac$SE <- datac$SD / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval:
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$CI <- datac$SE * ciMult
  
  return(datac)
  
}


wmapply <- function(x, width, FUN = NULL, ...){
  FUN <- match.fun(FUN)
  SEQ1 <- 1:length(x)
  SEQ1[SEQ1 <  width] <- NA_integer_
  SEQ2 <- lapply(SEQ1, function(i) if(!is.na(i)) (i - (width[i]-1)):i)
  OUT <- lapply(SEQ2, function(i) if(!is.null(i)) FUN(x[i], ...) else NA_real_)
  return(base:::simplify2array(OUT, higher = TRUE))
}
